@@ -35,7 +35,11 @@
 #'  \dontrun{
 #'
 #' # load example rtoi
-#' navarre <- read_rtoi(system.file("ex/Navarre",package="rsat"))
+#' file.copy(from=system.file("ex/Navarre",package="rsat"),
+#'          to=tempdir(),
+#'          recursive = TRUE)
+#'
+#' navarre <- read_rtoi(file.path(tempdir(),"Navarre"))
 #'
 #' print(navarre)
 #'
@@ -58,8 +62,11 @@
 #'
 #' plot(navarre, "preview")
 #'
+#' file.copy(from=system.file("ex/Pamplona",package="rsat"),
+#'          to=tempdir(),
+#'          recursive = TRUE)
 #' # plot already mosaicked rtoi ("view" mode)
-#' pamplona <- read_rtoi(system.file("ex/Pamplona",package="rsat"))
+#' pamplona <- read_rtoi(file.path(tempdir(),"Pamplona"))
 #'
 #' rsat_list_data(pamplona)
 #'
@@ -71,7 +78,12 @@
 #'      product = "mod09ga",
 #'      band_name = c("nir", "red", "green"))
 #'
-#' pamplona.derived <- read_rtoi(system.file("ex/PamplonaDerived",package="rsat"))
+#' file.copy(from=system.file("ex/PamplonaDerived",package="rsat"),
+#'          to=tempdir(),
+#'          recursive = TRUE)
+#' # plot already mosaicked rtoi ("view" mode)
+#' pamplona.derived <- read_rtoi(file.path(tempdir(),"PamplonaDerived"))
+#'
 #' rsat_list_data(pamplona.derived)
 #'
 #' # plot derived variables
@@ -682,7 +694,7 @@ genPlotGIS <- function(r,
       }
     }
   } else {
-    if ((class(zlim) != "numeric") & (length(zlim) != 0)) {
+    if ((!inherits(zlim,"numeric")) & (length(zlim) != 0)) {
       stop(paste0("zlim must be a vector of length 2 specifying",
                   " the upper and lower boundaries of the legend."))
     }
